@@ -2,15 +2,19 @@
 
 module Sentry
   class Session
-    attr_reader :started, :status
+    attr_reader :started, :status, :aggregation_key
 
     # TODO-neel add :crashed after adding handled mechanism
-    STATUSES = %i(ok errored exited)
-    AGGREGATE_STATUSES = %i(errored exited)
+    STATUSES = %i[ok errored exited]
+    AGGREGATE_STATUSES = %i[errored exited]
 
     def initialize
       @started = Sentry.utc_now
       @status = :ok
+
+      # truncate seconds from the timestamp since we only care about
+      # minute level granularity for aggregation
+      @aggregation_key = Time.utc(@started.year, @started.month, @started.day, @started.hour, @started.min)
     end
 
     # TODO-neel add :crashed after adding handled mechanism
@@ -22,12 +26,6 @@ module Sentry
       @status = :exited if @status == :ok
     end
 
-    # truncate seconds from the timestamp since we only care about
-    # minute level granularity for aggregation
-    def aggregation_key
-      Time.utc(started.year, started.month, started.day, started.hour, started.min)
-    end
-
     def deep_dup
       dup
     end
