@@ -3,7 +3,7 @@
 module Sentry
   module Utils
     module RequestId
-      REQUEST_ID_HEADERS = %w(action_dispatch.request_id HTTP_X_REQUEST_ID).freeze
+      REQUEST_ID_HEADERS = %w[action_dispatch.request_id HTTP_X_REQUEST_ID].freeze
 
       # Request ID based on ActionDispatch::RequestId
       def self.read_from(env)
